..
    This file is part of Invenio.
    Copyright (C) 2016 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.


Changes
=======

Version 0.2.2 (released 2016-07-06)

- Added CrawlerWorkflowObject to models
- Updates to support new invenio-workflows

Version 0.2.1 (released 2016-06-15)

- Package dependency fixes.

Version 0.2.0 (released 2016-06-09)

- Updates CrawlerJob database model to store results and logs paths.
- Makes sure invenio_oaiharvester receiver is producing parseable XML when
  receiving OAI-PMH records via the `oaiharvest_finished` signal.

Version 0.1.0 (released 2016-06-02)

- Initial public release.
